@@ -123,6 +123,12 @@ class MazeGenerator():
                 "The generated maze has been sized at 10x10")
             nrows = 10
             ncolumns = 10
+        r = nrows
+        c = ncolumns
+        deviation = (abs(c-(r+c)/2)/2)
+        nrows = int(min(r, c) + deviation)
+        ncolumns = int(max(r, c) - deviation)
+
         startPosition = 1
         pizzaPosition = 1
 
